<div align="center">
  <img alt="featurebox" src="https://github.com/boliqq07/featurebox/blob/master/img.jpg?raw=true">
</div>

[![Python Versions](https://img.shields.io/pypi/pyversions/featurebox.svg)](https://pypi.org/project/featurebox/)
[![Version](https://img.shields.io/github/tag/boliqq07/featurebox.svg)](https://github.com/boliqq07/releases/latest)
![pypi Versions](https://badge.fury.io/py/featurebox.svg)


Featurebox
----------------------
Welcome to Featurebox.

Featurebox is a open Python library that implements a comprehensive set of machine learning tools for materials
informatics.

Featurebox inspired by

[XenonPy](https://github.com/yoshida-lab/XenonPy),
[matminer](https://hackingmaterials.github.io/matminer/ ),
[sympy](https://www.sympy.org/en/index.html)


Document
----------------------
[featurebox document](https://featurebox.readthedocs.io/en/latest/)

Quick Install
----------------------

```bash
pip install featurebox
```

License
----------------------
GNU LGPL-3.0 License

Contact
----------------------
Developer: Boliqq07: 986798607@qq.com




